==> static_postgres_orm-0.0.2-dev.tar.gz: lib/src/postgres/orm_postgres_data_types.dart <==
import '../domain/orm_data_types.dart';

class IntegerField_PG extends IntegerField {
  IntegerField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);

  IntegerField_PG.clone(IntegerField_PG field) : super.clone(field);
}

class IntegerField_WithDefault_PG extends IntegerField_WithDefault {
  IntegerField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, int defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  IntegerField_WithDefault_PG.clone(IntegerField_WithDefault_PG field)
      : super.clone(field);
}

class NumericField_PG extends NumericField {
  late String _fieldName;
  @override
  String get columnNameToSelect =>
      'cast($_fieldName as DOUBLE PRECISION) as $_fieldName';

  NumericField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey) {
    _fieldName = fieldName;
  }
  NumericField_PG.clone(NumericField_PG field) : super.clone(field);
}

class NumericField_WithDefault_PG extends NumericField_WithDefault {
  late String _fieldName;
  @override
  String get columnNameToSelect =>
      'cast($_fieldName as DOUBLE PRECISION) as $_fieldName';
  NumericField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, double defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue) {
    _fieldName = fieldName;
  }
  NumericField_WithDefault_PG.clone(NumericField_WithDefault_PG field)
      : super.clone(field);
}

class StringField_PG extends StringField {
  StringField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey, maxLength)
      : super(owner, fieldName, notNullable, isPrimaryKey, maxLength);
  StringField_PG.clone(StringField_PG field) : super.clone(field);
}

class StringField_WithDefault_PG extends StringField_WithDefault {
  StringField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, int maxLength, String defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, maxLength,
            defaultValue);
  StringField_WithDefault_PG.clone(StringField_WithDefault_PG field)
      : super.clone(field);
}

class BooleanField_PG extends BooleanField {
  BooleanField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);
  BooleanField_PG.clone(BooleanField_PG field) : super.clone(field);
}

class BooleanField_WithDefault_PG extends BooleanField_WithDefault {
  BooleanField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, bool defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  BooleanField_WithDefault_PG.clone(BooleanField_WithDefault_PG field)
      : super.clone(field);
}

class DateField_PG extends DateField {
  DateField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);
  DateField_PG.clone(DateField_PG field) : super.clone(field);
}

class DateField_WithDefault_PG extends DateField_WithDefault {
  DateField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, DateTime defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  DateField_WithDefault_PG.clone(DateField_WithDefault_PG field)
      : super.clone(field);
}

class DateTimeField_PG extends DateTimeField {
  DateTimeField_PG(GenericDataFields owner, String fieldName, bool isPrimaryKey,
      bool notNullable)
      : super(owner, fieldName, isPrimaryKey, notNullable);
  DateTimeField_PG.clone(DateTimeField_PG field) : super.clone(field);
}

class DateTimeField_WithDefault_PG extends DateTimeField_WithDefault {
  DateTimeField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, DateTime defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  DateTimeField_WithDefault_PG.clone(DateTimeField_WithDefault_PG field)
      : super.clone(field);
}

class TimeField_PG extends TimeField {
  TimeField_PG(GenericDataFields owner, String fieldName, bool isPrimaryKey,
      bool notNullable)
      : super(owner, fieldName, isPrimaryKey, notNullable);
  TimeField_PG.clone(TimeField_PG field) : super.clone(field);
}

class TimeField_WithDefault_PG extends TimeField_WithDefault {
  TimeField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, DateTime defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  TimeField_WithDefault_PG.clone(TimeField_WithDefault_PG field)
      : super.clone(field);
}

==> static_postgres_orm-0.0.4-dev.tar.gz: lib/src/postgres/orm_postgres_data_types.dart <==
import '../domain/orm_data_types.dart';

class IntegerField_PG extends IntegerField {
  IntegerField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);

  IntegerField_PG.clone(IntegerField_PG field) : super.clone(field);
}

class IntegerField_WithDefault_PG extends IntegerField_WithDefault {
  IntegerField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, int defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  IntegerField_WithDefault_PG.clone(IntegerField_WithDefault_PG field)
      : super.clone(field);
}

class SerialField_PG extends SerialField {
  SerialField_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);
  SerialField_PG.clone(SerialField_PG field)
      : super.clone(field);
}

class NumericField_PG extends NumericField {
  late String _fieldName;
  @override
  String get columnNameToSelect =>
      'cast($_fieldName as DOUBLE PRECISION) as $_fieldName';

  NumericField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey) {
    _fieldName = fieldName;
  }
  NumericField_PG.clone(NumericField_PG field) : super.clone(field);
}

class NumericField_WithDefault_PG extends NumericField_WithDefault {
  late String _fieldName;
  @override
  String get columnNameToSelect =>
      'cast($_fieldName as DOUBLE PRECISION) as $_fieldName';
  NumericField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, double defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue) {
    _fieldName = fieldName;
  }
  NumericField_WithDefault_PG.clone(NumericField_WithDefault_PG field)
      : super.clone(field);
}

class StringField_PG extends StringField {
  StringField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey, maxLength)
      : super(owner, fieldName, notNullable, isPrimaryKey, maxLength);
  StringField_PG.clone(StringField_PG field) : super.clone(field);
}

class StringField_WithDefault_PG extends StringField_WithDefault {
  StringField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey,  int maxLength, String defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, maxLength,
            defaultValue);
  StringField_WithDefault_PG.clone(StringField_WithDefault_PG field)
      : super.clone(field);
}

class BooleanField_PG extends BooleanField {
  BooleanField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);
  BooleanField_PG.clone(BooleanField_PG field) : super.clone(field);
}

class BooleanField_WithDefault_PG extends BooleanField_WithDefault {
  BooleanField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, bool defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  BooleanField_WithDefault_PG.clone(BooleanField_WithDefault_PG field)
      : super.clone(field);
}

class DateField_PG extends DateField {
  DateField_PG(GenericDataFields owner, String fieldName, bool notNullable,
      bool isPrimaryKey)
      : super(owner, fieldName, notNullable, isPrimaryKey);
  DateField_PG.clone(DateField_PG field) : super.clone(field);
}

class DateField_WithDefault_PG extends DateField_WithDefault {
  DateField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, DateTime defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  DateField_WithDefault_PG.clone(DateField_WithDefault_PG field)
      : super.clone(field);
}

class DateTimeField_PG extends DateTimeField {
  DateTimeField_PG(GenericDataFields owner, String fieldName, bool isPrimaryKey,
      bool notNullable)
      : super(owner, fieldName, isPrimaryKey, notNullable);
  DateTimeField_PG.clone(DateTimeField_PG field) : super.clone(field);
}

class DateTimeField_WithDefault_PG extends DateTimeField_WithDefault {
  DateTimeField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, DateTime defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  DateTimeField_WithDefault_PG.clone(DateTimeField_WithDefault_PG field)
      : super.clone(field);
}

class TimeField_PG extends TimeField {
  TimeField_PG(GenericDataFields owner, String fieldName, bool isPrimaryKey,
      bool notNullable)
      : super(owner, fieldName, isPrimaryKey, notNullable);
  TimeField_PG.clone(TimeField_PG field) : super.clone(field);
}

class TimeField_WithDefault_PG extends TimeField_WithDefault {
  TimeField_WithDefault_PG(GenericDataFields owner, String fieldName,
      bool notNullable, bool isPrimaryKey, DateTime defaultValue)
      : super(owner, fieldName, notNullable, isPrimaryKey, defaultValue);
  TimeField_WithDefault_PG.clone(TimeField_WithDefault_PG field)
      : super.clone(field);
}
